/*! Copyright (c) 2007-2008 SAS Institute, Inc.  All rights reserved. */

/* ------------------------------------------------------------------------ *
 * Purpose: Contains the javascript classes and methods for the             *
 *          PromptPropertiesPanel class                                     *
 *                                                                          *
 * Author:                                                                  *
 * Version:  1.0                                                            *
 * ------------------------------------------------------------------------ */
sas.provides("sas_PromptProperties");
/*static fields */
sas_PromptPropertiesPanel.GROUP_PANEL_ID = "_group_panel";
sas_PromptPropertiesPanel.PROMPT_PROPERTY_CONTAINER_ID = "_container";
sas_PromptPropertiesPanel.NAV_COL_ID = "_navcolumn";
/*AJAX readyState code */
sas_PromptPropertiesPanel.SENDING_REQUEST 		= 0;
sas_PromptPropertiesPanel.LOADING_REQUEST 		= 1;
sas_PromptPropertiesPanel.RESPONSE_LOADED 		= 2;
sas_PromptPropertiesPanel.RESPONSE_INTERACTIVE 	= 3;
sas_PromptPropertiesPanel.RESPONSE_COMPLETE 	= 4;
sas_PromptPropertiesPanel.READY 				= 5;
/* Create PromptPropertyPanel JavaScript object*/
function sas_PromptPropertiesPanel(id, commitButtonId, dependentComponentId, previousGroup, autoSize) {
	this.previousGroup 			= previousGroup ? previousGroup : new Array;
	this.groups 				= 	new Array;

	this.addGroups(previousGroup);
    this.viewedModalGroupPanels = new Array;
    this.dependentComponentIds 	= dependentComponentId;
    this.previousGroupIndex 	= this.getSelectedGroupIndex();
    this.id 					= id;
    this.url 					= null;
	this.groupPanelObject 		= document.getElementById(id + sas_PromptPropertiesPanel.GROUP_PANEL_ID);

	this.requiredCheckBox 		= document.getElementById(this.id + "_requiredCheckBox");
    this.mode 					= "";
   	this.commitButtonId 		= commitButtonId;
   	this.readyState 			= sas_PromptPropertiesPanel.READY;
	this.activeComponent 		=  null;
	this.postPromptAjaxActionFunction	= null;
	this.applyOnFocus = false;
	this.validationFailed = false;
   	if (commitButtonId)
		this.commitButton 		= document.getElementById(commitButtonId);
    try {
    	this.promptValuesList = window[id+"_groupList_pgl_Obj"];
    }
    catch (e) {}
    this.promptGroupListContainer = document.getElementById(id+"_groupList_pgl_div");
    this.holderDiv = document.createElement("div");
    this.holderDiv.innerHTML = "<script></script>";
    this.errorDisplayed = false;
    var obj = this;
    if (autoSize) sas_registerEventHandler(window, 'load', function() { obj.resizePanel() });
}

sas_PromptPropertiesPanel.prototype.getBrowserHeight = function() {
	var bHeight = 0;
	if( typeof( window.innerWidth ) == 'number' ) {
    	//Non-IE
    	bHeight = window.innerHeight;
  	} else if( document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight ) ) {
    	//IE 6+ in 'standards compliant mode'
    	bHeight = document.documentElement.clientHeight;
  	} else if( document.body && ( document.body.clientWidth || document.body.clientHeight ) ) {
    //IE 4 compatible
    	bHeight = document.body.clientHeight;
  	}
  	return bHeight;
}

sas_PromptPropertiesPanel.prototype.resizePanel = function() {
	if (this.groupPanelObject) {
		this.groupPanelObject.style.height = "auto";
		this.groupPanelObject.style.height = "100%";
	}
	if (this.promptGroupListContainer) this.promptGroupListContainer.style.width = "auto";

	var groupListPanel = document.getElementById(this.id + "_groupList_pgl_Table");
	var h = this.getBrowserHeight();
	//browser size is too small
	if (h < 300) {
		if (groupListPanel && (groupListPanel.offsetHeight > 200)) {
			this.groupPanelObject.style.height = groupListPanel.offsetHeight + "px";
		}
		else if (this.groupPanelObject.offsetHeight > 300){
			this.groupPanelObject.style.height = "300px";
		}
	}
	else if (this.groupPanelObject.offsetHeight > 400) {
		if (groupListPanel && (groupListPanel.offsetHeight > h-200)) {
			this.groupPanelObject.style.height = groupListPanel.offsetHeight + "px";
		}
		else if (h > 500) {
			this.groupPanelObject.style.height = h-200+"px";
		}
		else
			this.groupPanelObject.style.height = "300px";
	}
}

sas_PromptPropertiesPanel.prototype.findPromptGroup = function(groupLabel) {
	var groups = this.getGroups();
	for (x in groups) {
		if (groups[x].groupLabel == groupLabel)
			return groups[x];
	}

}
sas_PromptPropertiesPanel.prototype.setApplyOnFocus = function(value) {
	this.applyOnFocus = value;
}

sas_PromptPropertiesPanel.prototype.isApplyOnFocus = function() {
	return this.applyOnFocus;
}

sas_PromptPropertiesPanel.prototype.findPromptComponent = function(promptName, groupName) {
	if (groupName) {
		return findComponent(promptName, this.findPromptGroup(groupName));
	}
	var groups = this.getGroups();
	for (x in groups) {
		var group = groups[x];
		return findComponent(promptName, group);
	}
	/* private function*/
	function findComponent(promptName, group) {
		var components = group.getComponents();
		for (y in components) {
			var component = components[y];
			if (component) {
				if (component.promptName == promptName) {
					return component;
				}
			}
		}
	}
}

sas_PromptPropertiesPanel.prototype.addGroups = function(group) {
	if ( sas_isArray(group) ) {
		for (x in group) {
			try {
				var groupObj = window [group[x]+"_Obj"];
				if (groupObj) this.groups.push(groupObj);
			}
			catch(e){  }
		}
	}
	else {
		this.groups.push(group);
	}
}
sas_PromptPropertiesPanel.prototype.getGroups = function() {
	return this.groups;
}

sas_PromptPropertiesPanel.prototype.hasPendingPrompt = function() {
	return (this.active) ? true : false;
}
sas_PromptPropertiesPanel.prototype.updatePendingPrompt = function() {
	if (this.hasPendingPrompt()) {
		if (this.active.component.apply) {
			this.active.component.apply();
		}
		else
			this.updateValue(this.active.id);
		this.active = null;
	}
}

sas_PromptPropertiesPanel.prototype.setPostPromptAjaxActionFunction = function(functionName) {
	this.postPromptAjaxActionFunction = functionName;
}

sas_PromptPropertiesPanel.prototype.getPostPromptAjaxActionFunction = function() {
	return this.postPromptAjaxActionFunction;
}
sas_PromptPropertiesPanel.prototype.makeRequest = function(url, handler, sync) {
    var self = this;
	this.protectPage(true);
	function _handler(type, data, xhr, options) {
		try {
			handler.call(self,type, data, xhr, options);
		}
		catch(e) {
			self.protectPage(false);
		}
		self.protectPage(false);
	}
	sas.ajax.send(url, null, _handler, null, ( (!sync) ? false : true));
}
sas_PromptPropertiesPanel.prototype.resetValue = function(name, value, range) {
    var promptComponent = window[name + "_Obj"];
    promptComponent.setValue(value);
    promptComponent.setCommitted(true);
}
sas_PromptPropertiesPanel.prototype.displayErrorDialog = function(message, promptName, value, promptComponentId) {
	this.inError = true;
	this.errorDisplayed = true;
    alert(message);
    try {
	    if (this.promptValuesList)
			this.promptValuesList.setSelectedIndex(this.previousGroupIndex);
	    var promptComponent = window[promptComponentId+"_Obj"];
	    if (promptComponent) {
	    	if (sas_isArray(value)) {
	    		promptComponent.setValue(value);
		    }
		    promptComponent.setCommitted(true);
    		//var promptObj = document.getElementById(promptName);
	    	//if (promptObj && promptObj.focus) {
    	    //	promptObj.focus();
	    	//}
	    }
    }
    catch (e) {}
    if (promptComponent)
	    promptComponent.focus();
    this.inError = false;

}
sas_PromptPropertiesPanel.prototype.isInError = function() {
	return this.inError;
}

sas_PromptPropertiesPanel.prototype.resetError = function() {
	this.inError = false;
}
sas_PromptPropertiesPanel.prototype.getSelectedGroupValue = function() {
	return ( (this.promptValuesList && this.promptValuesList.selectedNode) ? this.promptValuesList.selectedNode.value : this.id + "_" + this.defaultGroupName);
}

sas_PromptPropertiesPanel.prototype.getSelectedGroupIndex = function() {
	return ( (this.promptValuesList) ? this.promptValuesList.selectedIndex : 0);
}

sas_PromptPropertiesPanel.prototype.hideOptionalComponents = function(group, requiredChecked) {
	var optionalItems = group.getOptionalPromptComponents();
	for (x in optionalItems) {
		try {
			var comp = window[optionalItems[x] + "_Obj"];
			if (comp) {
				comp.setVisible(!requiredChecked.checked);
			}
		}
		catch (e){}
	}
	var subgroups = group.getGroups();
	for (x in subgroups) {
		try {
				var comp = window[subgroups[x] + "_Obj"];
				if (comp) {
					this.hideOptionalComponents(comp, requiredChecked);
				}
			}
			catch (e){}
	}
}

sas_PromptPropertiesPanel.prototype.showRequired = function(obj, ignorePending) {
	if (!ignorePending && this.hasPendingPrompt() && this.isApplyOnFocus()) {
		this.updatePendingPrompt();
	}
    this.mode = "requiredMode";
    try {
        groupName = this.getSelectedGroupValue();
        var groupObj = window[groupName + "_Obj"];
        if (groupObj) {
        	this.hideOptionalComponents(groupObj, obj);
        }
    }
    catch (e) {}
}
sas_PromptPropertiesPanel.prototype.setEnableRequiredCheckBox = function(requiredPromptPresent) {
	if (this.requiredCheckBox) {
		requiredPromptPresent ? this.requiredCheckBox.setEnabled(true) : this.requiredCheckBox.setEnabled(false);
	}
}
sas_PromptPropertiesPanel.prototype.switchGroup = function(selectedGroups, requiredPromptPresent) {
	if (this.hasPendingPrompt() && this.isApplyOnFocus()) {
		this.updatePendingPrompt();
	}
	if (this.previousGroupIndex == this.getSelectedGroupIndex()) return; //same group selected
	this.setEnableRequiredCheckBox(requiredPromptPresent);
    /* hide previous group and subgroups */
	if (this.previousGroup != null) {
		for (x in this.previousGroup) {
			try {
				var group = window[this.previousGroup[x] + "_Obj"];
				if (group) {
        	    	group.setVisible(false);
        	    }
          	}
          	catch (e) {}
		}
    }
    /* unhide selected group containers */
	for (x in selectedGroups) {
		try {
				var group = window[selectedGroups[x] + "_Obj"];
				if (group) {
        	    	group.setVisible(true);
        	    }
          }
          catch (e) {}
	}
	this.previousGroup = selectedGroups;

    var pComponent = this.previousComponent;
    if (pComponent) {
        if (pComponent.isModified() && !pComponent.isCommitted()) {
            pComponent.setCommitted(true);
       		//submit the previous pending value;
            this.updateValue(pComponent.id);
        }
    }
    this.previousGroupIndex = this.getSelectedGroupIndex();
    this.mode = "switchPanel";
    var groupObj = document.getElementById(this.promptValuesList.selectedNode.value + "_container");
	if (!this.isGroupVisible(groupObj)) {
		this.makeRequest(this.buildQueryString(), this.handleSwitchGroupPanel);
	}
	else {
		this.showRequired(document.getElementById(this.id + "_requiredCheckBox"));
	}
}
/**
 * Checks if the selected group is visible.
 * @param {Object} groupObj
 */
sas_PromptPropertiesPanel.prototype.isGroupVisible = function(groupObj) {
	if (groupObj) {
		try {
			if ( groupObj.innerHTML.length > 100 )
				return true;
			groupJsObj = window[this.promptValuesList.selectedNode.value+"_Obj"];
			if (groupJsObj) {
				var subgroups = groupJsObj.getGroups();
				for (x in subgroups) {
					subgroupJsObj = window[subgroups[x]+"_Obj"];
					if (subgroupJsObj && subgroupJsObj.container && subgroupJsObj.container.innerHTML.length < 100)
						return true;
				}
			}
		}
		catch (e){}
	}
	return false;
}

sas_PromptPropertiesPanel.prototype.buildQueryString = function(value, promptComponentId) {
    var parm = "";
    if (sas_isArray(value)) {
        for (index in value) {
          	var val= value[index];
          	if (val)
            	parm += "&sas_promptValue=" + encodeURIComponent(val);

        }
    } else if (value) {

	        parm += "&sas_promptValue=" + encodeURIComponent(value);
    }
    if (this.mode == "setValue") {
        //parm += "&ajaxAction=setPromptValues";
    } else {
        if (this.mode == "switchPanel") {
            parm += "&ajaxAction=switchGroupPanel";
        }
    }
    if (promptComponentId) {
        promptComponentObj = window[promptComponentId];
        if ( !promptComponentObj ) return;
        var name = promptComponentObj.getName();
        parm += "&sas_promptName=" + name + "&sas_groupName=" + promptComponentObj.groupName;
	    //parm += "&sas_promptName=" + name + "&sas_groupName=" + this.id + "_" + promptComponentObj.groupName;
        parm += "&sas_selectedGroupName=" + this.getSelectedGroupValue();
		var selectedIndex =  promptComponentObj.getSingleSelectionIndex();
		if (selectedIndex != -1) {
        //if (promptComponentObj.selectedIndex) {
        	parm += "&sas_selectedIndex=" + selectedIndex;
        }
    } else {
        parm += "&sas_groupName=" + this.getSelectedGroupValue();
    }
    var requiredCheckBox = document.getElementById(this.id + "_requiredCheckBox");
    var checked = false;
    if (requiredCheckBox) {
    	checked = requiredCheckBox.checked;
    }

    url = this.url + "&sas_selectedGroupIndex=" + this.getSelectedGroupIndex() + "&requiredChecked=" + checked + "&promptPropertyId=" + this.id;

    if (parm) {
        url = url + parm;
    }
    return url;
}


/* The prompt component will call this function when a server update is needed */
sas_PromptPropertiesPanel.prototype.updateValue = function(objId) {
	if (this.applyInProgress) {
		var self = this;
		window.setTimeout(function() { self.updateValue(objId); }, 100);
		return;
	}
    this.mode = "setValue";
    promptComponentObj = window[objId];
    if (!promptComponentObj) return false;
	if (promptComponentObj.isCommitted() && ( promptComponentObj.promptType == sas_PromptComponent.MULTIPLE || promptComponentObj.promptType == sas_PromptComponent.RANGE)) return false;
    var value = promptComponentObj.getValue(this.valueHandler, this, {objId: objId});
    if (!value)
    	value = "";
 	var url = this.buildQueryString(value, objId);
	url += "&ajaxAction=setPromptValues";

  	if (!promptComponentObj.serverValueUpdate)
	   	this.makeRequest(url, this.handlePromptValueUpdates, true);
    promptComponentObj.setCommitted(true);
	promptComponentObj.setModified(false);
	this.mode = "";

}

sas_PromptPropertiesPanel.prototype.valueHandler = function(value, args) {
	promptComponentObj = window[args.objId];
	if (!promptComponentObj) return;
	var url = this.buildQueryString(value, args.objId);
	if (promptComponentObj.serverValueUpdate)
    	   url = url + "&serverUpdate=true";
	if (promptComponentObj.selectedIndex > -1) {
		url = url+ "&sas_selectedIndex="+promptComponentObj.selectedIndex;
	}
   	url += "&ajaxAction=setPromptValues";
   	this.makeRequest(url, this.handlePromptValueUpdates, true);
	//promptComponentObj.setCommitted(true);
}
sas_PromptPropertiesPanel.prototype.handlePromptValueUpdates = function(type, data, xhr, options) {
        if (xhr.responseText.length > 0) {
			if (sas_checkSessionExpired(xhr.responseText)) return;
            var holderDiv = this.holderDiv;
            holderDiv.innerHTML = xhr.responseText;
			for (var i=0; i < holderDiv.childNodes.length; i++) {
                obj = holderDiv.childNodes[i];
                if (obj.id && obj.nodeName.toLowerCase() == "div") {
                    obj_holder = document.getElementById(obj.id);
                    if (obj_holder) {
                        obj_holder.innerHTML = obj.innerHTML;
                        //container empty .. hide it.
                        if (obj_holder.innerHTML.length > 20)
	                        obj_holder.style.display = "block";
						else {
							obj_holder.style.display = "none";
						}
                        if (obj.id.match("_PMG")) {
                            this.viewedModalGroupPanels.push(obj.id);
                        }
                    }
                }
            }
           sas.ajax.evalScripts(holderDiv);
          }
		  if (this.postPromptAjaxActionFunction && !this.errorDisplayed) {
			 	//window.setTimeout( this.postPromptAjaxActionFunction , 0);
			 	this.postPromptAjaxActionFunction();
			 	//this.setPostPromptAjaxActionFunction(null)
			 	var self = this;
				window.setTimeout( function() { self.setPostPromptAjaxActionFunction(null); }, 0);
		   }
		   this.errorDisplayed = false;
}
/* Handles the response text when switching the group panel */
sas_PromptPropertiesPanel.prototype.handleSwitchGroupPanel = function(type, data, xhr, options) {
        if (xhr.responseText.length > 0) {
			if (sas_checkSessionExpired(xhr.responseText)) return;
            var holderDiv = this.holderDiv;
            holderDiv.innerHTML = xhr.responseText;
			for (var i=0; i < holderDiv.childNodes.length; i++) {
				var obj = holderDiv.childNodes[i];
				if (obj && obj.id && obj.nodeName.toLowerCase() == "div") {
					obj_holder = document.getElementById(obj.id);
                    if (obj_holder) {
                        obj_holder.style.display = "block";
                        obj_holder.innerHTML = obj.innerHTML;

                    }
                    else {
                    	this.groupPanelObject.appendChild(obj);
                    }
				}
			}
            sas.ajax.evalScripts(holderDiv);
			if (this.postPromptAjaxActionFunction) {
			 	this.postPromptAjaxActionFunction.call();
				this.setPostPromptAjaxActionFunction(null);
			}
            holderDiv = null;
            this.showRequired(document.getElementById(this.id + "_requiredCheckBox"));
    }
}


sas_PromptPropertiesPanel.prototype.navToggle = function() {
    var panel = document.getElementById(this.id + "_navcolumn");
	var cpanel = document.getElementById("navCellCont");
	var expandCollapseImage = document.getElementById(this.id+"_expandCollapseImage");

	if (cpanel) {
		(cpanel.style.display == "none") ? cpanel.style.display = "block" : cpanel.style.display = "none";
	}
    if (panel) {
        (panel.style.display == "none") ? panel.style.display = "block" : panel.style.display = "none";
		if (expandCollapseImage) {
			if (panel.style.display == "none") {
				expandCollapseImage.src = this.collapseRightImage;
			} else {
				expandCollapseImage.src = this.collapseLeftImage;

			}
		}
    }
}
sas_PromptPropertiesPanel.prototype.updateGroupLabel = function(value, groupId) {
  var num_required = document.getElementById(groupId + "_required");
  var group_label = document.getElementById(groupId + "_label");
  if (num_required && value > 0) {
  	num_required.innerHTML = "(" + value + ")";
  	if (group_label)
  		group_label.style.fontWeight = "bold";
  }
  else {
  	if (num_required)
  		num_required.innerHTML = "";

  	if (group_label) {
  		group_label.style.fontWeight = "";
  	}
  }
}
sas_PromptPropertiesPanel.prototype.protectPage = function(protect) {

	if ( this.protectPageFunctionName && typeof this.protectPageFunctionName == 'function' ) {
		this.protectPageFunctionName.call(this,protect);
		return;
	}

    if (!window.fastClickManager || !this.fastClickProtectionEnabled) {
        return;
    }

    container = document.getElementById(this.id + "_container");
    var protectionAffectedObjects = [container];
    if (this.dependentComponentIds) {
    	for (var i=0; i < this.dependentComponentIds.length; i++) {
    		var obj = document.getElementById(this.dependentComponentIds[i]);
    		if (obj) {
    			protectionAffectedObjects.push(obj);
    		}
    	}
    }

    window.fastClickManager.setProtectionType("INCLUSIVE");
	window.fastClickManager.setProtectionAffectedObjects(protectionAffectedObjects);
    if (protect) {
        if (window.fastClickManager.protectPage != null && typeof fastClickManager.protectPage == "function") {
            window.fastClickManager.protectPage();
        }
    } else {
        if (window.fastClickManager.unprotectPage != null && typeof window.fastClickManager.unprotectPage == "function") {
			window.fastClickManager.unprotectPage();
        }
    }
}
sas_PromptPropertiesPanel.prototype.getCommitButton = function() {
	if (this.commitButton)
		return this.commitButton;
	if (this.commitButtonId) {
		try {
			this.commitButton = eval(this.commitButtonId + "_Obj");
		}
		catch (e){this.commitButton = document.getElementById(this.commitButtonId);}
		return this.commitButton;
	}
	return false;
}

sas_PromptPropertiesPanel.prototype.getReadyState = function() {
	if (!this.previousComponent)
		return sas_PromptPropertiesPanel.READY;
	return this.readyState;
}


sas_PromptPropertiesPanel.prototype.setCommitButtonEnable = function(status) {

	var button = this.getCommitButton();
	if (button && button.setEnabled)
		button.setEnabled(status);
	else if (button)
		button.disabled = !status;
}
sas_PromptPropertiesPanel.prototype.resetToDefault = function(groupId) {
	this.mode = "resetToDefault";
    var url = this.url;
	url += "&ajaxAction=resetToDefault&sas_selectedGroupName=" + groupId;
   	this.makeRequest(url, this.handleResetToDefault);
	this.mode = "";
}
sas_PromptPropertiesPanel.prototype.handleResetToDefault = function(type, data, xhr, options) {
    if (xhr.responseText.length > 0) {
		if (sas_checkSessionExpired(xhr.responseText)) return;
		var holderDiv = this.holderDiv;
        holderDiv.innerHTML = xhr.responseText;
        for (var i = 0; i < holderDiv.childNodes.length; i++) {
			obj = holderDiv.childNodes[i];
       	 	if (obj.nodeName.toLowerCase() == "div" && obj.id) {
        		obj_holder = document.getElementById(obj.id);
        	   	if (obj_holder) {
         	 		obj_holder.style.display = "block";
         	     	obj_holder.innerHTML = obj.innerHTML;
					//if value is a modal group; handle hiding unhiding here
        	     	if (obj.id.match("_PMG")) {
         	     		for (var j = 0; j < this.viewedModalGroupPanels.length; j++) {
           	    			if (document.getElementById(this.viewedModalGroupPanels[j]) && obj.id != this.viewedModalGroupPanels[j]) {
           		      	 		document.getElementById(this.viewedModalGroupPanels[j]).style.display = "none";
           		      		}
            	 		}
       				}
  				}
         	}
         }
         sas.ajax.evalScripts(holderDiv);
  	   	 this.showRequired(document.getElementById(this.id + "_requiredCheckBox"), true);
         holderDiv = null;
		 if (this.postPromptAjaxActionFunction) {
		 	this.postPromptAjaxActionFunction.call();
			this.setPostPromptAjaxActionFunction(null);
		 }
   }
}

sas_PromptPropertiesPanel.prototype.getRequiredPromptsWithoutValues = function(handler, jsObject) {
	if (!handler) return;
	this.mode = "getRequiredPromptsWithoutValues";
	if (this.hasPendingPrompt()) {
    	this.updatePendingPrompt();
  	}
	var url = this.url + "&ajaxAction=getRequiredPromptsWithoutValues";
	function _handler(type, data, xhr, options) {
			try {
				if (sas_checkSessionExpired(xhr.responseText)) return;
				eval(data);
				handler.call(jsObject ? jsObject : window, requiredPromptNames);
			}
			catch (e){}
	}
   	this.makeRequest(url, _handler);
	this.mode = "";
}

sas_PromptPropertiesPanel.prototype.isValidationFailed = function() {
	return this.validationFailed;
}

/****************************************************************************************/
/* JS Object for PromptGroups inside the prompt properties window 						*/
/****************************************************************************************/
function sas_PromptGroup(id, promptPropertyId, groupLabel) {
	this.containerId = id;
    this.container = document.getElementById(id);
    this.promptPropertyId = promptPropertyId;
    this.optionalComponents = new Array;
    this.groups = new Array;//subgroups
    this.components = new Array;
	this.groupLabel = groupLabel;
	try {
		var ppanel = window[promptPropertyId+"_Obj"];
		if (ppanel) ppanel.addGroups(this);
	}
	catch(e){}
	// S0442534 for IE need offline container to swap pickers in and out the DOM hierarchy
	//if (dojo.render.html.ie)
	//	this.dummyDiv=document.createElement('div');
}
sas_PromptGroup.prototype.setOptionalPromptComponents = function (components) {
    this.optionalComponents = components;
};

sas_PromptGroup.prototype.addComponents = function (component) {
	if (sas_isArray(component)) {
		for (x in component) {
			try {
				var compObj = window[component[x]+"_Obj"];
				if (compObj) {
					this.components.push(compObj);
				}
			}
			catch(e){}
		}
	}
	else {
		this.components.push(component);
	}

}

sas_PromptGroup.prototype.getComponents = function() {
	return this.components;
}

sas_PromptGroup.prototype.setVisible = function(visible) {
	if (this.container) {
		// S0442534 for IE move online pickers from DOM hierarchy to offline container and viceversa.
		// DOM need refreshing. Instead of movingChildren into a "dummy" div, use replaceNode to cause a refresh.
		if (dojo.render.html.ie) {
			if (!visible)	dojo.dom.replaceNode(this.container,this.container);
			//visible ? dojo.dom.moveChildren(this.dummyDiv,this.container) : dojo.dom.moveChildren(this.container,this.dummyDiv) ;
		}
		this.container.style.display = (visible ? "block" : "none");
		for (var i=0; i < groups.length; i++) {
			var groupObj = window[groups[i]+"_Obj"];
			if (groupObj) {
				groupObj.setVisible(visible);
			}
		}
	}
}

sas_PromptGroup.prototype.setGroups = function (groups) {
    this.groups = groups;
};
sas_PromptGroup.prototype.getOptionalPromptComponents = function () {
    return this.optionalComponents;
};
sas_PromptGroup.prototype.getGroups = function () {
    return this.groups;
};
